Skip to contents

A translation table for the variable gss_cat, a data source from the General Social Survey that is included in the package forcats and used for examples in transcats.

Usage

gss_translation

Format

gss_translation

A list of tibbles, each with three columns named "en", "es", "fr". Their names correspond to the categorical variables involved: marital, race, rincome, partyid, relig, denom.