Skip to contents

Changes the value of tcats$var_name_table, the currently active table for translating variable names.

Usage

set_var_name_table(vartable)

Arguments

vartable

A horizontal translation table whose column names correspond to variables

Value

Former value of the parameter.