R/variable_name.R
var_lang.Rd
This functions provides a shortened call to variable_name using preset values for the language and variable name table.
var_lang(...)
Name of the variable, without quotes
A text string that is the title of the variable
var_lang(tvhours) #> Warning: No translation found for tvhours. #> [1] "tvhours"