A translation table for the variable gss_cat, a data source from the
General Social Survey that is included in the package forcats
and used for examples in transcats.
A translation table for the variable gss_cat, a data source from the
General Social Survey that is included in the package forcats
and used for examples in transcats.