A variable name translation table for the variable gss_cat,
a data source from the General Social Survey that is included
in the package forcats and used for examples in transcats.
gss_var_table
A data frame with 4 rows and 10 columns. The rows correspond to
English, Spanish, French and the r_variable. The final row matches the
names of the columns. Rows are indexted by language codes in the variable
language.
Created as part of transcats