R/aaa.R
set_var_name_table.Rd
Changes the value of tcats$var_name_table, the currently active table for translating variable names.
set_var_name_table(vartable)
A horizontal translation table whose column names correspond to variables
Former value of the parameter.