R/variable_name.R
var_lang_str.Rd
This functions provides a shortened call to variable_name using preset values for the language and variable name table.
var_lang_str(...)
Name of the variable, passed as a string, in quotes
A text string that is the title of the variable
var_lang_str("tvhours") #> Warning: No translation found for tvhours. #> [1] "tvhours"